# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

account: Optional[str]
"""
Spotinst Account ID
"""

enabled: Optional[bool]
"""
Enable or disable the Spotinst provider
"""

featureFlags: Optional[str]
"""
Spotinst SDK Feature Flags
"""

token: Optional[str]
"""
Spotinst Personal API Access Token
"""

